<?php

/**
 * @file
 * Theme hooks provided by the Node Link Display module.
 */

/**
 * Returns HTML for a styled node link.
 *
 * @param $name
 *   The name of the link as defined in the hook.
 * @param $link
 *   An array containing the return of the hook_link() implementation.
 * @param $config
 *   An array containing the configurations.
 *
 * @return
 *   A string containing the HTML for the node link.
 *
 * @ingroup themeable
 */
function theme_node_link_style_link($name, $link, $config, $options=NULL) {
   $output = '';
  
  // Open the wrapper element.
  if (!empty($config['element'])) {

    // Builds wrapper element attributes.
    if (empty($config['apply_attributes'])) {
      $class = $name;
      if (!empty($config['class'])) {
        $class = $config['class'];  //new class isn't appended anymore to existing classes. All the classes have to be specified. It avoids issues with declaration order.
      }
      $attributes = drupal_attributes(array('class' => $class));
    }
    else {
      $attributes = '';
      if (isset($link['attributes'])) {
        if (empty($link['attributes']['class'])) {
          $link['attributes']['class'] = $name;
        }
        else {
          $link['attributes']['class'] = $name; //new class isn't appended anymore to existing classes. All the classes have to be specified. It avoids issues with declaration order.
        }
        $attributes = drupal_attributes($link['attributes']);
      }
    }

    // Initializes the element
    $element = check_plain($config['element']);
    $output .= '<' . $element . $attributes . '>';
  }

  // Add the link or text.
  if (!empty($options)&&!empty($options['custom_group']))
      $output .= theme('node_link_style_custom_group_item', $link, $config, $options);
  else {
    if (isset($link['href'])) {
      if (!empty($options)&&!empty($options['custom_group']))
        $output .= theme('node_link_style_custom_group_item', $link, $config, $options);
      else
        $output .= l(_get_title($link, $config),  $link['href'], $link);
    }
    elseif (!empty($link['title'])) {
      if (empty($link['html'])) {
        $link['title'] = check_plain($link['title']);
      }
      $output .= $link['title'];
    }
  }

  // Close the wrapper element.
  if (!empty($config['element'])) {
    $output .= '</' . $element . '>';
  }

  // Returns themed link.
  return $output;
}

/**
 * Returns HTML for a styled group of node links.
 *
 * @param $name
 *   The name of the link as defined in the hook.
 * @param $links
 *   An array containing the return of the hook_link() implementation.
 * @param $config
 *   An array containing the configurations.
 *
 * @return
 *   A string containing the HTML for the node link.
 *
 * @ingroup themeable
 */

function theme_node_link_style_group($links, $config) {
  global $language;
  $output = '';
  
  $drop_down=FALSE;
  $list_name;
  $drop_down_form_name;
  $drop_down_input_name;

  // Gets link count, gets list elements and attributes.
  $num_links = count($links);
  $list_element = check_plain($config['list_element']);
  $list_attributes = drupal_attributes(array('class' => $config['list_class']));

  // Gets item element based on list type.
  switch ($list_element) {
    case 'custom' :
      $drop_down=TRUE;
    case 'ul':
    case 'ol':
      $item_element = 'li';
      break;
    default:
      $item_element = 'dt';
    break;
  }

  // Builds the list.
  if ($num_links) {
    if (!$drop_down) {
      $output .= '<' . $list_element . $list_attributes . '>';
    }

    $i = 1;
    foreach ($links as $name => $link) {
      $class = $name;
      if ($i==1) $list_name=$name;
      if ($drop_down&&$i==1)
        $output .= theme('node_link_style_custom_group', $list_name, $link, $config, $options, TRUE);
      else{
        // Add first, last and active classes.
        if ($i == 1) {
          $class .= ' first';
        }
        if ($i == $num_links) {
          $class .= ' last';
        }
      }
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page()))
      && (empty($link['language']) || $link['language']->language == $language->language)) {
        $class .= ' active';
      }

      // Builds list item via theme_node_link_style_link().
      $options=array();
      if ($drop_down) { //to pass list name to node_link_style_link
        $options['custom_group']=TRUE;
        $options['list_name']=$list_name;
        $options['first']=($i == 1);
        $options['last']=($i == $num_links);
      }
      else {
        $output .= '<' . $item_element . drupal_attributes(array('class' => $class)) . '>';
      }
      $output .= theme('node_link_style_link', $name, $link, $config, $options);
      if (!$drop_down)
        $output .= "</$item_element>\n";

      // Increments row count.
      $i++;
    }

    // Finalizes the list.
    if ($drop_down) {
      $output .= theme('node_link_style_custom_group', $list_name, $link, $config, $options, FALSE);      
    }
    else {
      $output .= '</' . $list_element . '>';
    }
  }

  // Returnes the themed group.
  return $output;
}

/**
* Returns HTML for link separator. Adds a separator between styled links and normal node links.
*
* @return
*   A string containing the HTML for the link separator.
*
* @ingroup themeable
*/
function theme_node_link_style_separator() {
  //return '<div class="styled-links-separator"></div>';
}

/**
 * Overrides default link title
 * 
 * @return title
 */
function _get_title($link, $config) {
  if (empty($config['title'])) $title=$link['title'];
  else $title=t($config['title']);
  return $title;
}

/**
 *
 * @return
 *   HTML for drop down item.
 *
 * @ingroup themeable
 */
function theme_node_link_style_custom_group_item($link, $config, $options) {
}
/**
 *
 * @return
 *   HTML for drop down item.
 *
 * @ingroup themeable
 */
function theme_node_link_style_custom_group($list_name, $link, $config, $options, $start=TRUE) {
}

